[![PyPI](https://img.shields.io/pypi/v/wipac-dev-next-version-action-testbed)](https://pypi.org/project/wipac-dev-next-version-action-testbed/) [![GitHub release (latest by date including pre-releases)](https://img.shields.io/github/v/release/WIPACrepo/wipac-dev-next-version-action-testbed?include_prereleases)](https://github.com/WIPACrepo/wipac-dev-next-version-action-testbed/) [![Versions](https://img.shields.io/pypi/pyversions/wipac-dev-next-version-action-testbed.svg)](https://pypi.org/project/wipac-dev-next-version-action-testbed)

# wipac-dev-next-version-action-testbed

A guinea pig for testing the `wipac-dev-next-version-action`
